@@ -7,14 +7,7 @@
 #' @param data Numerical values, either a dataframe or a matrix
 #' @param well Vector of well identifers e.g "A01"
 #' @param plate_id Vector of plate identifiers e.g "Plate_1"
-#' @param ncols Number of columns to display multiple plates
-#' @param plate Number of wells in complete plate (96, 384 or 1536)
-#' @param threshold Threshold of +/- standard deviations form the average
-#'     to determine a hit
-#' @param each boolean, if true scales each plate individually, if false will
-#'     scale the pooled values of \code{data}
-#' @param palette RColorBrewer palette
-#'
+#' @param ... additional arguments to `platetools::hit_grid()`
 #' @return ggplot plot
 #'
 #' @import ggplot2
@@ -42,26 +35,9 @@
 #'   plate_id = df$plate,
 #'   plate = 96)
 
-pchit_grid <- function(data, well,
-                      plate_id,
-                      ncols = 2,
-                      plate = 96,
-                      threshold = 2,
-                      each = FALSE,
-                      palette = "Spectral"){
-
+pchit_grid <- function(data, well, plate_id, ...) {
     pca_data <- prcomp(data) # pca of data
     pc1 <- pca_data$x[,1] # take first principal component
-
-    pc_hit_grid <- hit_grid(pc1,
-        well = well,
-        plate_id = plate_id,
-	    ncols = ncols,
-	    plate = plate,
-	    each,
-	    threshold = threshold,
-	    palette = palette)
-
+    pc_hit_grid <- hit_grid(pc1, well = well, plate_id = plate_id, ...)
     return(pc_hit_grid)
-
 }
